;;; nerd-icons-data-pomicon.el --- glyphset pomicon -*- lexical-binding: t -*-

;; Copyright (C) 2023 Hongyu Ding <rainstormstudio@yahoo.com>

;; Author: Hongyu Ding <rainstormstudio@yahoo.com>
;; Keywords: lisp

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; pomicon
;; from Nerd Font Version: 3.4.0

;;; Code:

(defvar nerd-icons/pomicon-alist
  '(
    ("nf-pom-away" . "\xe007")
    ("nf-pom-clean_code" . "\xe000")
    ("nf-pom-external_interruption" . "\xe00a")
    ("nf-pom-internal_interruption" . "\xe009")
    ("nf-pom-long_pause" . "\xe006")
    ("nf-pom-pair_programming" . "\xe008")
    ("nf-pom-pomodoro_done" . "\xe001")
    ("nf-pom-pomodoro_estimated" . "\xe002")
    ("nf-pom-pomodoro_squashed" . "\xe004")
    ("nf-pom-pomodoro_ticking" . "\xe003")
    ("nf-pom-short_pause" . "\xe005")
    ))

(provide 'nerd-icons-data-pomicon)
;;; nerd-icons-data-pomicon.el ends here