;;; nerd-icons-data-ipsicon.el --- glyphset ipsicon -*- lexical-binding: t -*-

;; Copyright (C) 2023 Hongyu Ding <rainstormstudio@yahoo.com>

;; Author: Hongyu Ding <rainstormstudio@yahoo.com>
;; Keywords: lisp

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; ipsicon
;; from Nerd Font Version: 3.4.0

;;; Code:

(defvar nerd-icons/ipsicon-alist
  '(
    ("nf-iec-power" . "\x23fb")
    ("nf-iec-power_off" . "\x2b58")
    ("nf-iec-power_on" . "\x23fd")
    ("nf-iec-sleep_mode" . "\x23fe")
    ("nf-iec-toggle_power" . "\x23fc")
    ))

(provide 'nerd-icons-data-ipsicon)
;;; nerd-icons-data-ipsicon.el ends here