;;; nerd-icons-data-flicon.el --- glyphset flicon -*- lexical-binding: t -*-

;; Copyright (C) 2023 Hongyu Ding <rainstormstudio@yahoo.com>

;; Author: Hongyu Ding <rainstormstudio@yahoo.com>
;; Keywords: lisp

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; flicon
;; from Nerd Font Version: 3.4.0

;;; Code:

(defvar nerd-icons/flicon-alist
  '(
    ("nf-linux-almalinux" . "\xf31d")
    ("nf-linux-alpine" . "\xf300")
    ("nf-linux-aosc" . "\xf301")
    ("nf-linux-apple" . "\xf302")
    ("nf-linux-archcraft" . "\xf345")
    ("nf-linux-archlabs" . "\xf31e")
    ("nf-linux-archlinux" . "\xf303")
    ("nf-linux-arcolinux" . "\xf346")
    ("nf-linux-arduino" . "\xf34b")
    ("nf-linux-artix" . "\xf31f")
    ("nf-linux-awesome" . "\xf354")
    ("nf-linux-biglinux" . "\xf347")
    ("nf-linux-bspwm" . "\xf355")
    ("nf-linux-budgie" . "\xf320")
    ("nf-linux-centos" . "\xf304")
    ("nf-linux-cinnamon" . "\xf35f")
    ("nf-linux-codeberg" . "\xf330")
    ("nf-linux-coreos" . "\xf305")
    ("nf-linux-crystal" . "\xf348")
    ("nf-linux-debian" . "\xf306")
    ("nf-linux-deepin" . "\xf321")
    ("nf-linux-devuan" . "\xf307")
    ("nf-linux-docker" . "\xf308")
    ("nf-linux-dwm" . "\xf356")
    ("nf-linux-elementary" . "\xf309")
    ("nf-linux-endeavour" . "\xf322")
    ("nf-linux-enlightenment" . "\xf357")
    ("nf-linux-fdroid" . "\xf36a")
    ("nf-linux-fedora" . "\xf30a")
    ("nf-linux-fedora_inverse" . "\xf30b")
    ("nf-linux-ferris" . "\xf323")
    ("nf-linux-flathub" . "\xf324")
    ("nf-linux-fluxbox" . "\xf358")
    ("nf-linux-forgejo" . "\xf335")
    ("nf-linux-fosdem" . "\xf36b")
    ("nf-linux-freebsd" . "\xf30c")
    ("nf-linux-freecad" . "\xf336")
    ("nf-linux-freedesktop" . "\xf360")
    ("nf-linux-garuda" . "\xf337")
    ("nf-linux-gentoo" . "\xf30d")
    ("nf-linux-gimp" . "\xf338")
    ("nf-linux-gitea" . "\xf339")
    ("nf-linux-gnome" . "\xf361")
    ("nf-linux-gnu_guix" . "\xf325")
    ("nf-linux-gtk" . "\xf362")
    ("nf-linux-hyperbola" . "\xf33a")
    ("nf-linux-hyprland" . "\xf359")
    ("nf-linux-i3" . "\xf35a")
    ("nf-linux-illumos" . "\xf326")
    ("nf-linux-inkscape" . "\xf33b")
    ("nf-linux-jwm" . "\xf35b")
    ("nf-linux-kali_linux" . "\xf327")
    ("nf-linux-kde" . "\xf373")
    ("nf-linux-kde_neon" . "\xf331")
    ("nf-linux-kde_plasma" . "\xf332")
    ("nf-linux-kdenlive" . "\xf33c")
    ("nf-linux-kicad" . "\xf34c")
    ("nf-linux-krita" . "\xf33d")
    ("nf-linux-kubuntu" . "\xf333")
    ("nf-linux-kubuntu_inverse" . "\xf334")
    ("nf-linux-leap" . "\xf37e")
    ("nf-linux-libreoffice" . "\xf376")
    ("nf-linux-libreofficebase" . "\xf377")
    ("nf-linux-libreofficecalc" . "\xf378")
    ("nf-linux-libreofficedraw" . "\xf379")
    ("nf-linux-libreofficeimpress" . "\xf37a")
    ("nf-linux-libreofficemath" . "\xf37b")
    ("nf-linux-libreofficewriter" . "\xf37c")
    ("nf-linux-linuxmint" . "\xf30e")
    ("nf-linux-linuxmint_inverse" . "\xf30f")
    ("nf-linux-locos" . "\xf349")
    ("nf-linux-lxde" . "\xf363")
    ("nf-linux-lxle" . "\xf33e")
    ("nf-linux-lxqt" . "\xf364")
    ("nf-linux-mageia" . "\xf310")
    ("nf-linux-mandriva" . "\xf311")
    ("nf-linux-manjaro" . "\xf312")
    ("nf-linux-mate" . "\xf365")
    ("nf-linux-mpv" . "\xf36e")
    ("nf-linux-mxlinux" . "\xf33f")
    ("nf-linux-neovim" . "\xf36f")
    ("nf-linux-nixos" . "\xf313")
    ("nf-linux-nobara" . "\xf380")
    ("nf-linux-octoprint" . "\xf34d")
    ("nf-linux-openbsd" . "\xf328")
    ("nf-linux-openscad" . "\xf34e")
    ("nf-linux-opensuse" . "\xf314")
    ("nf-linux-osh" . "\xf34f")
    ("nf-linux-oshwa" . "\xf350")
    ("nf-linux-osi" . "\xf36c")
    ("nf-linux-parabola" . "\xf340")
    ("nf-linux-parrot" . "\xf329")
    ("nf-linux-pop_os" . "\xf32a")
    ("nf-linux-postmarketos" . "\xf374")
    ("nf-linux-prusaslicer" . "\xf351")
    ("nf-linux-puppy" . "\xf341")
    ("nf-linux-qt" . "\xf375")
    ("nf-linux-qtile" . "\xf35c")
    ("nf-linux-qubesos" . "\xf342")
    ("nf-linux-raspberry_pi" . "\xf315")
    ("nf-linux-redhat" . "\xf316")
    ("nf-linux-reprap" . "\xf352")
    ("nf-linux-riscv" . "\xf353")
    ("nf-linux-river" . "\xf381")
    ("nf-linux-rocky_linux" . "\xf32b")
    ("nf-linux-sabayon" . "\xf317")
    ("nf-linux-slackware" . "\xf318")
    ("nf-linux-slackware_inverse" . "\xf319")
    ("nf-linux-snappy" . "\xf32c")
    ("nf-linux-solus" . "\xf32d")
    ("nf-linux-sway" . "\xf35d")
    ("nf-linux-tails" . "\xf343")
    ("nf-linux-thunderbird" . "\xf370")
    ("nf-linux-tor" . "\xf371")
    ("nf-linux-trisquel" . "\xf344")
    ("nf-linux-tumbleweed" . "\xf37d")
    ("nf-linux-tux" . "\xf31a")
    ("nf-linux-typst" . "\xf37f")
    ("nf-linux-ubuntu" . "\xf31b")
    ("nf-linux-ubuntu_inverse" . "\xf31c")
    ("nf-linux-vanilla" . "\xf366")
    ("nf-linux-void" . "\xf32e")
    ("nf-linux-vscodium" . "\xf372")
    ("nf-linux-wayland" . "\xf367")
    ("nf-linux-wikimedia" . "\xf36d")
    ("nf-linux-xerolinux" . "\xf34a")
    ("nf-linux-xfce" . "\xf368")
    ("nf-linux-xmonad" . "\xf35e")
    ("nf-linux-xorg" . "\xf369")
    ("nf-linux-zorin" . "\xf32f")
    ))

(provide 'nerd-icons-data-flicon)
;;; nerd-icons-data-flicon.el ends here