;;; nerd-icons-data.el --- Nerd Icons data -*- lexical-binding: t -*-

;; Copyright (C) 2023 Hongyu Ding <rainstormstudio@yahoo.com>

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; nerd icons data

;;; Code:

(require 'nerd-icons-data-ipsicon   "./data/nerd-icons-data-ipsicon")
(require 'nerd-icons-data-pomicon   "./data/nerd-icons-data-pomicon")
(require 'nerd-icons-data-octicon   "./data/nerd-icons-data-octicon")
(require 'nerd-icons-data-powerline "./data/nerd-icons-data-powerline")
(require 'nerd-icons-data-faicon    "./data/nerd-icons-data-faicon")
(require 'nerd-icons-data-wicon     "./data/nerd-icons-data-wicon")
(require 'nerd-icons-data-sucicon   "./data/nerd-icons-data-sucicon")
(require 'nerd-icons-data-devicon   "./data/nerd-icons-data-devicon")
(require 'nerd-icons-data-codicon   "./data/nerd-icons-data-codicon")
(require 'nerd-icons-data-flicon    "./data/nerd-icons-data-flicon")
(require 'nerd-icons-data-mdicon    "./data/nerd-icons-data-mdicon")

(provide 'nerd-icons-data)
;;; nerd-icons-data.el ends here
