;;; nerd-icons-data-powerline.el --- glyphset powerline -*- lexical-binding: t -*-

;; Copyright (C) 2023 Hongyu Ding <rainstormstudio@yahoo.com>

;; Author: Hongyu Ding <rainstormstudio@yahoo.com>
;; Keywords: lisp

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; powerline
;; from Nerd Font Version: 3.4.0

;;; Code:

(defvar nerd-icons/powerline-alist
  '(
    ("nf-pl-branch" . "\xe0a0")
    ("nf-pl-current_line" . "\xe0a1")
    ("nf-pl-hostname" . "\xe0a2")
    ("nf-pl-left_hard_divider" . "\xe0b0")
    ("nf-pl-left_soft_divider" . "\xe0b1")
    ("nf-pl-line_number" . "\xe0a1")
    ("nf-pl-readonly" . "\xe0a2")
    ("nf-pl-right_hard_divider" . "\xe0b2")
    ("nf-pl-right_soft_divider" . "\xe0b3")
    ("nf-ple-backslash_separator" . "\xe0b9")
    ("nf-ple-backslash_separator_redundant" . "\xe0bf")
    ("nf-ple-column_number" . "\xe0a3")
    ("nf-ple-current_column" . "\xe0a3")
    ("nf-ple-flame_thick" . "\xe0c0")
    ("nf-ple-flame_thick_mirrored" . "\xe0c2")
    ("nf-ple-flame_thin" . "\xe0c1")
    ("nf-ple-flame_thin_mirrored" . "\xe0c3")
    ("nf-ple-forwardslash_separator" . "\xe0bb")
    ("nf-ple-forwardslash_separator_redundant" . "\xe0bd")
    ("nf-ple-honeycomb" . "\xe0cc")
    ("nf-ple-honeycomb_outline" . "\xe0cd")
    ("nf-ple-ice_waveform" . "\xe0c8")
    ("nf-ple-ice_waveform_mirrored" . "\xe0ca")
    ("nf-ple-left_half_circle_thick" . "\xe0b6")
    ("nf-ple-left_half_circle_thin" . "\xe0b7")
    ("nf-ple-left_hard_divider_inverse" . "\xe0d7")
    ("nf-ple-lego_block_facing" . "\xe0d0")
    ("nf-ple-lego_block_sideways" . "\xe0d1")
    ("nf-ple-lego_separator" . "\xe0ce")
    ("nf-ple-lego_separator_thin" . "\xe0cf")
    ("nf-ple-lower_left_triangle" . "\xe0b8")
    ("nf-ple-lower_right_triangle" . "\xe0ba")
    ("nf-ple-pixelated_squares_big" . "\xe0c6")
    ("nf-ple-pixelated_squares_big_mirrored" . "\xe0c7")
    ("nf-ple-pixelated_squares_small" . "\xe0c4")
    ("nf-ple-pixelated_squares_small_mirrored" . "\xe0c5")
    ("nf-ple-right_half_circle_thick" . "\xe0b4")
    ("nf-ple-right_half_circle_thin" . "\xe0b5")
    ("nf-ple-right_hard_divider_inverse" . "\xe0d6")
    ("nf-ple-trapezoid_top_bottom" . "\xe0d2")
    ("nf-ple-trapezoid_top_bottom_mirrored" . "\xe0d4")
    ("nf-ple-upper_left_triangle" . "\xe0bc")
    ("nf-ple-upper_right_triangle" . "\xe0be")
    ))

(provide 'nerd-icons-data-powerline)
;;; nerd-icons-data-powerline.el ends here