;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "nerd-icons" "20260424.1510"
  "Emacs Nerd Font Icons Library."
  '((emacs "25.1"))
  :url "https://github.com/rainstormstudio/nerd-icons.el"
  :commit "3f6e8b36436d99659234d5bbbd84ba5c09282692"
  :revdesc "3f6e8b36436d"
  :keywords '("lisp")
  :authors '(("Hongyu Ding" . "rainstormstudio@yahoo.com")
             ("Vincent Zhang" . "seagle0128@gmail.com"))
  :maintainers '(("Hongyu Ding" . "rainstormstudio@yahoo.com")
                 ("Vincent Zhang" . "seagle0128@gmail.com")))
