;;; nerd-icons-data-wicon.el --- glyphset wicon -*- lexical-binding: t -*-

;; Copyright (C) 2023 Hongyu Ding <rainstormstudio@yahoo.com>

;; Author: Hongyu Ding <rainstormstudio@yahoo.com>
;; Keywords: lisp

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; wicon
;; from Nerd Font Version: 3.4.0

;;; Code:

(defvar nerd-icons/wicon-alist
  '(
    ("nf-weather-alien" . "\xe36e")
    ("nf-weather-aliens" . "\xe345")
    ("nf-weather-barometer" . "\xe372")
    ("nf-weather-celsius" . "\xe339")
    ("nf-weather-cloud" . "\xe33d")
    ("nf-weather-cloud_down" . "\xe33a")
    ("nf-weather-cloud_refresh" . "\xe33b")
    ("nf-weather-cloud_up" . "\xe33c")
    ("nf-weather-cloudy" . "\xe312")
    ("nf-weather-cloudy_gusts" . "\xe310")
    ("nf-weather-cloudy_windy" . "\xe311")
    ("nf-weather-day_cloudy" . "\xe302")
    ("nf-weather-day_cloudy_gusts" . "\xe300")
    ("nf-weather-day_cloudy_high" . "\xe376")
    ("nf-weather-day_cloudy_windy" . "\xe301")
    ("nf-weather-day_fog" . "\xe303")
    ("nf-weather-day_hail" . "\xe304")
    ("nf-weather-day_haze" . "\xe3ae")
    ("nf-weather-day_light_wind" . "\xe3bc")
    ("nf-weather-day_lightning" . "\xe305")
    ("nf-weather-day_rain" . "\xe308")
    ("nf-weather-day_rain_mix" . "\xe306")
    ("nf-weather-day_rain_wind" . "\xe307")
    ("nf-weather-day_showers" . "\xe309")
    ("nf-weather-day_sleet" . "\xe3aa")
    ("nf-weather-day_sleet_storm" . "\xe362")
    ("nf-weather-day_snow" . "\xe30a")
    ("nf-weather-day_snow_thunderstorm" . "\xe365")
    ("nf-weather-day_snow_wind" . "\xe35f")
    ("nf-weather-day_sprinkle" . "\xe30b")
    ("nf-weather-day_storm_showers" . "\xe30e")
    ("nf-weather-day_sunny" . "\xe30d")
    ("nf-weather-day_sunny_overcast" . "\xe30c")
    ("nf-weather-day_thunderstorm" . "\xe30f")
    ("nf-weather-day_windy" . "\xe37d")
    ("nf-weather-degrees" . "\xe33e")
    ("nf-weather-direction_down" . "\xe340")
    ("nf-weather-direction_down_left" . "\xe33f")
    ("nf-weather-direction_down_right" . "\xe380")
    ("nf-weather-direction_left" . "\xe344")
    ("nf-weather-direction_right" . "\xe349")
    ("nf-weather-direction_up" . "\xe353")
    ("nf-weather-direction_up_left" . "\xe37f")
    ("nf-weather-direction_up_right" . "\xe352")
    ("nf-weather-dust" . "\xe35d")
    ("nf-weather-earthquake" . "\xe3be")
    ("nf-weather-fahrenheit" . "\xe341")
    ("nf-weather-fire" . "\xe3bf")
    ("nf-weather-flood" . "\xe375")
    ("nf-weather-fog" . "\xe313")
    ("nf-weather-gale_warning" . "\xe3c5")
    ("nf-weather-hail" . "\xe314")
    ("nf-weather-horizon" . "\xe343")
    ("nf-weather-horizon_alt" . "\xe342")
    ("nf-weather-hot" . "\xe36b")
    ("nf-weather-humidity" . "\xe373")
    ("nf-weather-hurricane" . "\xe36c")
    ("nf-weather-hurricane_warning" . "\xe3c7")
    ("nf-weather-lightning" . "\xe315")
    ("nf-weather-lunar_eclipse" . "\xe369")
    ("nf-weather-meteor" . "\xe36a")
    ("nf-weather-moon_alt_first_quarter" . "\xe3ce")
    ("nf-weather-moon_alt_full" . "\xe3d5")
    ("nf-weather-moon_alt_new" . "\xe3e3")
    ("nf-weather-moon_alt_third_quarter" . "\xe3dc")
    ("nf-weather-moon_alt_waning_crescent_1" . "\xe3dd")
    ("nf-weather-moon_alt_waning_crescent_2" . "\xe3de")
    ("nf-weather-moon_alt_waning_crescent_3" . "\xe3df")
    ("nf-weather-moon_alt_waning_crescent_4" . "\xe3e0")
    ("nf-weather-moon_alt_waning_crescent_5" . "\xe3e1")
    ("nf-weather-moon_alt_waning_crescent_6" . "\xe3e2")
    ("nf-weather-moon_alt_waning_gibbous_1" . "\xe3d6")
    ("nf-weather-moon_alt_waning_gibbous_2" . "\xe3d7")
    ("nf-weather-moon_alt_waning_gibbous_3" . "\xe3d8")
    ("nf-weather-moon_alt_waning_gibbous_4" . "\xe3d9")
    ("nf-weather-moon_alt_waning_gibbous_5" . "\xe3da")
    ("nf-weather-moon_alt_waning_gibbous_6" . "\xe3db")
    ("nf-weather-moon_alt_waxing_crescent_1" . "\xe3c8")
    ("nf-weather-moon_alt_waxing_crescent_2" . "\xe3c9")
    ("nf-weather-moon_alt_waxing_crescent_3" . "\xe3ca")
    ("nf-weather-moon_alt_waxing_crescent_4" . "\xe3cb")
    ("nf-weather-moon_alt_waxing_crescent_5" . "\xe3cc")
    ("nf-weather-moon_alt_waxing_crescent_6" . "\xe3cd")
    ("nf-weather-moon_alt_waxing_gibbous_1" . "\xe3cf")
    ("nf-weather-moon_alt_waxing_gibbous_2" . "\xe3d0")
    ("nf-weather-moon_alt_waxing_gibbous_3" . "\xe3d1")
    ("nf-weather-moon_alt_waxing_gibbous_4" . "\xe3d2")
    ("nf-weather-moon_alt_waxing_gibbous_5" . "\xe3d3")
    ("nf-weather-moon_alt_waxing_gibbous_6" . "\xe3d4")
    ("nf-weather-moon_first_quarter" . "\xe394")
    ("nf-weather-moon_full" . "\xe39b")
    ("nf-weather-moon_new" . "\xe38d")
    ("nf-weather-moon_third_quarter" . "\xe3a2")
    ("nf-weather-moon_waning_crescent_1" . "\xe3a3")
    ("nf-weather-moon_waning_crescent_2" . "\xe3a4")
    ("nf-weather-moon_waning_crescent_3" . "\xe3a5")
    ("nf-weather-moon_waning_crescent_4" . "\xe3a6")
    ("nf-weather-moon_waning_crescent_5" . "\xe3a7")
    ("nf-weather-moon_waning_crescent_6" . "\xe3a8")
    ("nf-weather-moon_waning_gibbous_1" . "\xe39c")
    ("nf-weather-moon_waning_gibbous_2" . "\xe39d")
    ("nf-weather-moon_waning_gibbous_3" . "\xe39e")
    ("nf-weather-moon_waning_gibbous_4" . "\xe39f")
    ("nf-weather-moon_waning_gibbous_5" . "\xe3a0")
    ("nf-weather-moon_waning_gibbous_6" . "\xe3a1")
    ("nf-weather-moon_waxing_crescent_1" . "\xe38e")
    ("nf-weather-moon_waxing_crescent_2" . "\xe38f")
    ("nf-weather-moon_waxing_crescent_3" . "\xe390")
    ("nf-weather-moon_waxing_crescent_4" . "\xe391")
    ("nf-weather-moon_waxing_crescent_5" . "\xe392")
    ("nf-weather-moon_waxing_crescent_6" . "\xe393")
    ("nf-weather-moon_waxing_gibbous_1" . "\xe395")
    ("nf-weather-moon_waxing_gibbous_2" . "\xe396")
    ("nf-weather-moon_waxing_gibbous_3" . "\xe397")
    ("nf-weather-moon_waxing_gibbous_4" . "\xe398")
    ("nf-weather-moon_waxing_gibbous_5" . "\xe399")
    ("nf-weather-moon_waxing_gibbous_6" . "\xe39a")
    ("nf-weather-moonrise" . "\xe3c1")
    ("nf-weather-moonset" . "\xe3c2")
    ("nf-weather-na" . "\xe374")
    ("nf-weather-night_alt_cloudy" . "\xe37e")
    ("nf-weather-night_alt_cloudy_gusts" . "\xe31f")
    ("nf-weather-night_alt_cloudy_high" . "\xe377")
    ("nf-weather-night_alt_cloudy_windy" . "\xe320")
    ("nf-weather-night_alt_hail" . "\xe321")
    ("nf-weather-night_alt_lightning" . "\xe322")
    ("nf-weather-night_alt_partly_cloudy" . "\xe379")
    ("nf-weather-night_alt_rain" . "\xe325")
    ("nf-weather-night_alt_rain_mix" . "\xe323")
    ("nf-weather-night_alt_rain_wind" . "\xe324")
    ("nf-weather-night_alt_showers" . "\xe326")
    ("nf-weather-night_alt_sleet" . "\xe3ac")
    ("nf-weather-night_alt_sleet_storm" . "\xe364")
    ("nf-weather-night_alt_snow" . "\xe327")
    ("nf-weather-night_alt_snow_thunderstorm" . "\xe367")
    ("nf-weather-night_alt_snow_wind" . "\xe361")
    ("nf-weather-night_alt_sprinkle" . "\xe328")
    ("nf-weather-night_alt_storm_showers" . "\xe329")
    ("nf-weather-night_alt_thunderstorm" . "\xe32a")
    ("nf-weather-night_clear" . "\xe32b")
    ("nf-weather-night_cloudy" . "\xe32e")
    ("nf-weather-night_cloudy_gusts" . "\xe32c")
    ("nf-weather-night_cloudy_high" . "\xe378")
    ("nf-weather-night_cloudy_windy" . "\xe32d")
    ("nf-weather-night_fog" . "\xe346")
    ("nf-weather-night_hail" . "\xe32f")
    ("nf-weather-night_lightning" . "\xe330")
    ("nf-weather-night_partly_cloudy" . "\xe37b")
    ("nf-weather-night_rain" . "\xe333")
    ("nf-weather-night_rain_mix" . "\xe331")
    ("nf-weather-night_rain_wind" . "\xe332")
    ("nf-weather-night_showers" . "\xe334")
    ("nf-weather-night_sleet" . "\xe3ab")
    ("nf-weather-night_sleet_storm" . "\xe363")
    ("nf-weather-night_snow" . "\xe335")
    ("nf-weather-night_snow_thunderstorm" . "\xe366")
    ("nf-weather-night_snow_wind" . "\xe360")
    ("nf-weather-night_sprinkle" . "\xe336")
    ("nf-weather-night_storm_showers" . "\xe337")
    ("nf-weather-night_thunderstorm" . "\xe338")
    ("nf-weather-rain" . "\xe318")
    ("nf-weather-rain_mix" . "\xe316")
    ("nf-weather-rain_wind" . "\xe317")
    ("nf-weather-raindrop" . "\xe371")
    ("nf-weather-raindrops" . "\xe34a")
    ("nf-weather-refresh" . "\xe348")
    ("nf-weather-refresh_alt" . "\xe347")
    ("nf-weather-sandstorm" . "\xe37a")
    ("nf-weather-showers" . "\xe319")
    ("nf-weather-sleet" . "\xe3ad")
    ("nf-weather-small_craft_advisory" . "\xe3c4")
    ("nf-weather-smog" . "\xe36d")
    ("nf-weather-smoke" . "\xe35c")
    ("nf-weather-snow" . "\xe31a")
    ("nf-weather-snow_wind" . "\xe35e")
    ("nf-weather-snowflake_cold" . "\xe36f")
    ("nf-weather-solar_eclipse" . "\xe368")
    ("nf-weather-sprinkle" . "\xe31b")
    ("nf-weather-stars" . "\xe370")
    ("nf-weather-storm_showers" . "\xe31c")
    ("nf-weather-storm_warning" . "\xe3c6")
    ("nf-weather-strong_wind" . "\xe34b")
    ("nf-weather-sunrise" . "\xe34c")
    ("nf-weather-sunset" . "\xe34d")
    ("nf-weather-thermometer" . "\xe350")
    ("nf-weather-thermometer_exterior" . "\xe34e")
    ("nf-weather-thermometer_internal" . "\xe34f")
    ("nf-weather-thunderstorm" . "\xe31d")
    ("nf-weather-time_1" . "\xe382")
    ("nf-weather-time_10" . "\xe38b")
    ("nf-weather-time_11" . "\xe38c")
    ("nf-weather-time_12" . "\xe381")
    ("nf-weather-time_2" . "\xe383")
    ("nf-weather-time_3" . "\xe384")
    ("nf-weather-time_4" . "\xe385")
    ("nf-weather-time_5" . "\xe386")
    ("nf-weather-time_6" . "\xe387")
    ("nf-weather-time_7" . "\xe388")
    ("nf-weather-time_8" . "\xe389")
    ("nf-weather-time_9" . "\xe38a")
    ("nf-weather-tornado" . "\xe351")
    ("nf-weather-train" . "\xe3c3")
    ("nf-weather-tsunami" . "\xe3bd")
    ("nf-weather-umbrella" . "\xe37c")
    ("nf-weather-volcano" . "\xe3c0")
    ("nf-weather-wind_beaufort_0" . "\xe3af")
    ("nf-weather-wind_beaufort_1" . "\xe3b0")
    ("nf-weather-wind_beaufort_10" . "\xe3b9")
    ("nf-weather-wind_beaufort_11" . "\xe3ba")
    ("nf-weather-wind_beaufort_12" . "\xe3bb")
    ("nf-weather-wind_beaufort_2" . "\xe3b1")
    ("nf-weather-wind_beaufort_3" . "\xe3b2")
    ("nf-weather-wind_beaufort_4" . "\xe3b3")
    ("nf-weather-wind_beaufort_5" . "\xe3b4")
    ("nf-weather-wind_beaufort_6" . "\xe3b5")
    ("nf-weather-wind_beaufort_7" . "\xe3b6")
    ("nf-weather-wind_beaufort_8" . "\xe3b7")
    ("nf-weather-wind_beaufort_9" . "\xe3b8")
    ("nf-weather-wind_direction" . "\xe3a9")
    ("nf-weather-wind_east" . "\xe35b")
    ("nf-weather-wind_north" . "\xe35a")
    ("nf-weather-wind_north_east" . "\xe359")
    ("nf-weather-wind_north_west" . "\xe358")
    ("nf-weather-wind_south" . "\xe357")
    ("nf-weather-wind_south_east" . "\xe356")
    ("nf-weather-wind_south_west" . "\xe355")
    ("nf-weather-wind_west" . "\xe354")
    ("nf-weather-windy" . "\xe31e")
    ))

(provide 'nerd-icons-data-wicon)
;;; nerd-icons-data-wicon.el ends here